summaryrefslogtreecommitdiff
path: root/web/share/js
diff options
context:
space:
mode:
authorMaxim Devaev <[email protected]>2021-09-08 06:47:54 +0300
committerMaxim Devaev <[email protected]>2021-09-08 06:47:54 +0300
commit8f11fa3b91921a6037b56ead0853928b1404de0f (patch)
tree45c002095795db7b8a23e5043d16b46a89e9485a /web/share/js
parentca812117e48cbc6e2c71947b912748cfd3ff9691 (diff)
small rebranding
Diffstat (limited to 'web/share/js')
-rw-r--r--web/share/js/bb.js2
-rw-r--r--web/share/js/index/main.js6
-rw-r--r--web/share/js/ipmi/main.js2
-rw-r--r--web/share/js/keypad.js2
-rw-r--r--web/share/js/kvm/atx.js2
-rw-r--r--web/share/js/kvm/gpio.js2
-rw-r--r--web/share/js/kvm/hid.js2
-rw-r--r--web/share/js/kvm/keyboard.js4
-rw-r--r--web/share/js/kvm/main.js4
-rw-r--r--web/share/js/kvm/mouse.js4
-rw-r--r--web/share/js/kvm/msd.js4
-rw-r--r--web/share/js/kvm/recorder.js2
-rw-r--r--web/share/js/kvm/session.js8
-rw-r--r--web/share/js/kvm/stream.js2
-rw-r--r--web/share/js/login/main.js2
-rw-r--r--web/share/js/tools.js2
-rw-r--r--web/share/js/vnc/main.js2
-rw-r--r--web/share/js/wm.js2
18 files changed, 27 insertions, 27 deletions
diff --git a/web/share/js/bb.js b/web/share/js/bb.js
index 709a5fb6..871ea75a 100644
--- a/web/share/js/bb.js
+++ b/web/share/js/bb.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/ipmi/main.js b/web/share/js/ipmi/main.js
index 70eda686..87a444b6 100644
--- a/web/share/js/ipmi/main.js
+++ b/web/share/js/ipmi/main.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/keypad.js b/web/share/js/keypad.js
index 69e6dba9..6ada18f8 100644
--- a/web/share/js/keypad.js
+++ b/web/share/js/keypad.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/kvm/atx.js b/web/share/js/kvm/atx.js
index b0978b2c..3c0bf6c0 100644
--- a/web/share/js/kvm/atx.js
+++ b/web/share/js/kvm/atx.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/kvm/gpio.js b/web/share/js/kvm/gpio.js
index e1c93553..85f6070b 100644
--- a/web/share/js/kvm/gpio.js
+++ b/web/share/js/kvm/gpio.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/kvm/hid.js b/web/share/js/kvm/hid.js
index bf508e0b..c53c039c 100644
--- a/web/share/js/kvm/hid.js
+++ b/web/share/js/kvm/hid.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/kvm/recorder.js b/web/share/js/kvm/recorder.js
index e3b40667..3de98056 100644
--- a/web/share/js/kvm/recorder.js
+++ b/web/share/js/kvm/recorder.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/kvm/stream.js b/web/share/js/kvm/stream.js
index c56ca15c..14f5ecfc 100644
--- a/web/share/js/kvm/stream.js
+++ b/web/share/js/kvm/stream.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/login/main.js b/web/share/js/login/main.js
index 40a7894d..13e352f8 100644
--- a/web/share/js/login/main.js
+++ b/web/share/js/login/main.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/tools.js b/web/share/js/tools.js
index 61ac3e1d..98ffa5f7 100644
--- a/web/share/js/tools.js
+++ b/web/share/js/tools.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/vnc/main.js b/web/share/js/vnc/main.js
index fdfe742b..d7ee1738 100644
--- a/web/share/js/vnc/main.js
+++ b/web/share/js/vnc/main.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/wm.js b/web/share/js/wm.js
index 4ac4e4e5..f45dabd0 100644
--- a/web/share/js/wm.js
+++ b/web/share/js/wm.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
diff --git a/web/share/js/index/main.js b/web/share/js/index/main.js
index 535959d9..0f20ee10 100644
--- a/web/share/js/index/main.js
+++ b/web/share/js/index/main.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -90,10 +90,10 @@ function __loadKvmdInfo() {
if (info.meta !== null && info.meta.server && info.meta.server.host) {
$("kvmd-meta-server-host").innerHTML = info.meta.server.host;
- document.title = `Pi-KVM Index: ${info.meta.server.host}`;
+ document.title = `PiKVM Index: ${info.meta.server.host}`;
} else {
$("kvmd-meta-server-host").innerHTML = "";
- document.title = "Pi-KVM Index";
+ document.title = "PiKVM Index";
}
} else if (http.status === 401 || http.status === 403) {
document.location.href = "/login";
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
diff --git a/web/share/js/kvm/keyboard.js b/web/share/js/kvm/keyboard.js
index 7c632d40..49e9c76c 100644
--- a/web/share/js/kvm/keyboard.js
+++ b/web/share/js/kvm/keyboard.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -123,7 +123,7 @@ export function Keyboard(__recordWsEvent) {
}
} else {
if (is_captured) {
- title = "Keyboard captured, Pi-KVM offline";
+ title = "Keyboard captured, PiKVM offline";
}
}
$("hid-keyboard-led").className = led;
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
diff --git a/web/share/js/kvm/main.js b/web/share/js/kvm/main.js
index 8ab47b2c..4c4b662b 100644
--- a/web/share/js/kvm/main.js
+++ b/web/share/js/kvm/main.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -33,7 +33,7 @@ import {Session} from "./session.js";
export function main() {
if (checkBrowser()) {
window.onbeforeunload = function(event) {
- let text = "Are you sure you want to close Pi-KVM session?";
+ let text = "Are you sure you want to close PiKVM session?";
event.returnValue = text;
return text;
};
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
diff --git a/web/share/js/kvm/mouse.js b/web/share/js/kvm/mouse.js
index 1c33e4c0..7a0a50f3 100644
--- a/web/share/js/kvm/mouse.js
+++ b/web/share/js/kvm/mouse.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -142,7 +142,7 @@ export function Mouse(__getResolution, __recordWsEvent) {
}
} else {
if (is_captured) {
- title = "Mouse captured, Pi-KVM offline";
+ title = "Mouse captured, PiKVM offline";
}
}
$("hid-mouse-led").className = led;
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
diff --git a/web/share/js/kvm/msd.js b/web/share/js/kvm/msd.js
index 93551c31..6999697f 100644
--- a/web/share/js/kvm/msd.js
+++ b/web/share/js/kvm/msd.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -71,7 +71,7 @@ export function Msd() {
var __clickRemoveButton = function() {
let name = $("msd-image-selector").value;
- wm.confirm(`Are you sure you want to remove the image<br><b>${name}</b> from Pi-KVM?`).then(function(ok) {
+ wm.confirm(`Are you sure you want to remove the image<br><b>${name}</b> from PiKVM?`).then(function(ok) {
if (ok) {
let http = tools.makeRequest("POST", `/api/msd/remove?image=${name}`, function() {
if (http.readyState === 4) {
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
diff --git a/web/share/js/kvm/session.js b/web/share/js/kvm/session.js
index af328f56..061b235f 100644
--- a/web/share/js/kvm/session.js
+++ b/web/share/js/kvm/session.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -59,7 +59,7 @@ export function Session() {
if (state !== null) {
let text = JSON.stringify(state, undefined, 4).replace(/ /g, "&nbsp;").replace(/\n/g, "<br>");
$("about-meta").innerHTML = `
- <span class="code-comment">// The Pi-KVM metadata.<br>
+ <span class="code-comment">// The PiKVM metadata.<br>
// You can get this JSON using handle <a target="_blank" href="/api/info?fields=meta">/api/info?fields=meta</a>.<br>
// In the standard configuration this data<br>
// is specified in the file /etc/kvmd/meta.yaml.</span><br>
@@ -68,10 +68,10 @@ export function Session() {
`;
if (state.server && state.server.host) {
$("kvmd-meta-server-host").innerHTML = `Server: ${state.server.host}`;
- document.title = `Pi-KVM Session: ${state.server.host}`;
+ document.title = `PiKVM Session: ${state.server.host}`;
} else {
$("kvmd-meta-server-host").innerHTML = "";
- document.title = "Pi-KVM Session";
+ document.title = "PiKVM Session";
}
// Don't use this option, it may be removed in any time
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #